
#include <stdio.h>

#include "ip_connection.h"
#include "bricklet_temperature_ir.h"

#define HOST "localhost"
#define PORT 4223
#define UID "abcde" // Change to your UID

// Callback functions for object/ambient temperature callbacks
// (parameters have unit °C/10)
void cb_object(uint16_t temperature) {
	printf("Object Temperature: %f °C.\n", temperature/10.0);
}

void cb_ambient(uint16_t temperature) {
	printf("Ambient Temperature: %f °C.\n", temperature/10.0);
}

int main() {
	// Create IP connection to brickd
	IPConnection ipcon;
	if(ipcon_create(&ipcon, HOST, PORT) < 0) {
		fprintf(stderr, "Could not create connection\n");
		exit(1);
	}

	// Create device object
	TemperatureIR tir;
	temperature_ir_create(&tir, UID); 

	// Add device to IP connection
	if(ipcon_add_device(&ipcon, &tir) < 0) {
		fprintf(stderr, "Could not connect to Bricklet\n");
		exit(1);
	}
	// Don't use device before it is added to a connection

	// Set Period for temperature callbacks to 1s (1000ms)
	// Note: The callbacks are only called every second if the 
	//       value has changed since the last call!
	temperature_ir_set_object_temperature_callback_period(&tir, 1000);
	temperature_ir_set_ambient_temperature_callback_period(&tir, 1000);

	// Register object temperature callback to function cb_object
	temperature_ir_register_callback(&tir,
	                                 TEMPERATURE_IR_CALLBACK_OBJECT_TEMPERATURE, 
	                                 cb_object);

	// Register ambient temperature callback to function cb_ambient
	temperature_ir_register_callback(&tir,
	                                 TEMPERATURE_IR_CALLBACK_AMBIENT_TEMPERATURE, 
	                                 cb_ambient);

	printf("Press key to exit\n");
	getchar();
	ipcon_destroy(&ipcon);
}
